function [ processed_inline ] = process_inline( p_inline )
%PROCESS_INLINE Searches the given inline text by the Iridium information and extracts them.
%   Processes the given inline text and extracts the iridium information.
%   
%   Parameters:
%   p_inline:           The inline text to be processed.
%
%   Returns:
%   processed_inline:   Struct, containing the found information. Contains
%                       false on fail.

%% Initialize return variable
processed_inline = false;

%% Parameter check
if (~ischar(p_inline))
    warning([mfilename ': Wrong parameter given. Please check them carefully!']);
    return;
end

%% Initialize values to extract
utc = 'Time of Session (UTC): ';
momsn = 'MOMSN: ';
mtmsn = 'MTMSN: ';
session_status = 'Session Status: ';
message_size_in_bytes = 'Message Size (bytes): ';
unit_location = 'Unit Location: ';
cep_radius = 'CEPradius = ';

%% Split message by lines
lines = strsplit(p_inline, '\n');

% find values and store them

location = process_if_available(unit_location);
if (~isa(location, 'logical'))
    location = strsplit(strtrim(location));
    iridium_lat = str2double(location{3});
    iridium_lon = str2double(location{6});
else
    iridium_lat = false;
    iridium_lon = false;
end

processed_inline = struct( ...
    'TIMEOFSESSION',  process_if_available(utc), ...
    'MOMSN',  process_if_available(momsn), ...
    'MTMSN',  process_if_available(mtmsn), ...
    'SESSIONSTATUS',  process_if_available(session_status), ...
    'MESSAGESIZE',  process_if_available(message_size_in_bytes), ...
    'IRIDIUM_LAT',  iridium_lat, ...
    'IRIDIUM_LON',  iridium_lon, ...
    'CEPRAD',  process_if_available(cep_radius) ...
);


%% Convert to usable matlab values
if (~isa(processed_inline.TIMEOFSESSION, 'logical'))
    processed_inline.TIMEOFSESSION = datevec(processed_inline.TIMEOFSESSION, 'ddd mmm dd HH:MM:SS yyyy');
end
if (~isa(processed_inline.MOMSN, 'logical'))
    processed_inline.MOMSN = str2double(processed_inline.MOMSN);
end
if (~isa(processed_inline.MTMSN, 'logical'))
    processed_inline.MTMSN = str2double(processed_inline.MTMSN);
end
if (~isa(processed_inline.MESSAGESIZE, 'logical'))
    processed_inline.MESSAGESIZE = str2double(processed_inline.MESSAGESIZE);
end
if (~isa(processed_inline.CEPRAD, 'logical'))
    processed_inline.CEPRAD = str2double(processed_inline.CEPRAD);
end

    function value = process_if_available(p_variable)
        value = false;
        try
            value = lines{find(~cellfun(@isempty, strfind(lines, p_variable)))}(length(p_variable):end);
        catch ex
            return
        end
    end

end

