function [ boolean, rfb_floats ] = create_and_save_collection( p_nemo_floats, p_config, p_metadata )
%CREATE_AND_SAVE_COLLECTION Creates the rfb structure from a collection of nemo floats and saves them to disk.
%   
%   Parameters:
%   p_nemo_floats:          The nemo data.
%   p_config:               The nemo configuration.
%   p_metadata:             The nemo metadata.
%
%   Returns:
%   boolean:                True, if successful.
%   rfb_floats:             The rfb structure.

%% Initialize return variable
boolean = false;

%% Parameter check
parameter_error = false;

if (~iscell(p_nemo_floats) || ~isstruct(p_config) || ~iscell(p_metadata))
    parameter_error = true;
end

if (parameter_error) % display error message
    disp([ mfilename ': Wrong parameter! Please check your input parameters carefully!']);
    return;
else % do some cleanup
    clear parameter_error;
end

%% Collect necessary information and save all rfb files

output_files = cellfun(...
    @(x) [ p_config.RFB.output_path sprintf('%04d', x{1}.FLOAT_IDENTIFICATION.float_serial_number) '.rfb'] ...
    , p_nemo_floats, 'UniformOutput', false);

p_metadata = nemo.sync_metadata_to_nemodata(p_nemo_floats, p_metadata);

[rfb_floats, ~] = nemo.rfb.create(p_nemo_floats, p_metadata);

booleans = cellfun(@nemo.rfb.save, rfb_floats, output_files, cell(length(rfb_floats), 1));

if (all(booleans))
    boolean = true;
else
    boolean = false;
end

end

